const path = require("path");
const fs = require("fs");
var HTMLWebpackPlugin = require("html-webpack-plugin");

const walkSync = (dir, filelist = []) => {
    fs.readdirSync(dir).forEach((file) => {
        filelist = fs.statSync(path.join(dir, file)).isDirectory() ?
            walkSync(path.join(dir, file), filelist) :
            filelist.concat(path.join(dir, file));
    });
    return filelist;
};

const dir = "src/pages";
const pages = walkSync(dir).map((el) => el.slice(dir.length + 1));

console.log(pages);

module.exports = {
    entry: {
        index: "./src/index.js",
        content: "./src/js/content.js",
        members: "./src/js/members.js",
        attributions: "./src/js/attributions.js"
    },
    output: {
        filename: "[name].bundle.js",
        path: path.resolve(__dirname, "dist"),
    },
    devtool: "none",
    plugins: [
        new HTMLWebpackPlugin({
            filename: "index.html",
            template: "./src/index.pug",
            excludeChunks: ["content", "members", "attributions"],
        }),
        ...pages.map(
            (page) =>
            new HTMLWebpackPlugin({
                template: "./src/pages/" + page,
                filename: page.slice(0, -4) + "/index.html",
                excludeChunks: ["index", "members", "attributions"],
            })
        )
    ],
    module: {
        rules: [{
            test: /\.pug$/,
            use: ["pug-loader"],
        }, ],
    },
};